# Database Test Mocker
![pyver](https://img.shields.io/badge/python-3.6%2B-blue)

Pacote para criação e população de banco de dados para execução de testes.

### Variáveis de ambiente

Este projeto depende das variáveis de ambiente abaixo.

```bash
MYSQL_HOST=
MYSQL_USER=
MYSQL_PASS=
MYSQL_DATABASE=
MYSQL_PORT=
```


```python

```

